@@ -27,7 +27,6 @@
 #include <QDebug>
 #include <QTcpServer>
 
-#include <QDebug>
 #include <QFile>
 #include <qtest.h>
 
@@ -70,7 +69,7 @@ void FakeServer::dataAvailable()
     QMutexLocker locker(&m_mutex);
 
     QTcpSocket *socket = qobject_cast<QTcpSocket *>(sender());
-    QVERIFY(socket != 0);
+    QVERIFY(socket);
 
     int scenarioNumber = m_clientSockets.indexOf(socket);
 
