@@ -68,7 +68,7 @@ public:
     /**
      * The quota root that resource limit information will be fetched for.
      */
-    QByteArray root() const;
+    Q_REQUIRED_RESULT QByteArray root() const;
 
 protected:
     void doStart() override;
